<template>
    <div class="table-wrapper">
        <ht-table
            @load="loadData"
            :data="data"
            :pageResult="pageResult"
            :selectable="false"
            :show-custom-column="false"
            :show-export="false"
            ref="htTable"
            class="table-refoom"
            :default-sorter="[{direction: 'DESC', property: 'id_'}]"
        >
            <template>
                <ht-table-column
                    prop="indexNo"
                    label="序号"
                    width="55"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="reformDepart"
                    label="整改方"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="reformDate"
                    label="整改时间"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="reformDescription"
                    label="整改结果描述"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="reformOpinion"
                    label="整改意见"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column prop="" label="操作" :show-overflow-tooltip="true">
                    <template slot-scope="{row}">
                        <el-button @click="handleDetail(row)">
                            <i class="el-icon-view" style="margin-right: 5px" /> 详情
                        </el-button>
                    </template>
                </ht-table-column>
            </template>
        </ht-table>
        <el-dialog
            title="质量管理整改"
            :visible.sync="dialogVisible"
            width="800px"
            :before-close="handleCloseDialog"
            :close-on-click-modal="false"
            v-if="dialogVisible"
            modal-append-to-body
            append-to-body
            top="8vh"
        >
            <el-form
                ref="form"
                v-form
                data-vv-scope="form"
                :model="form"
                :rules="userRules"
                label-width="110px"
            >
                <el-row>
                    <el-col :span="24">
                        <el-form-item label="整改时间" prop="reformDate">
                            <el-date-picker
                                v-model="form.reformDate"
                                type="date"
                                placeholder="选择日期"
                                format="yyyy-MM-dd"
                                value-format="yyyy-MM-dd"
                                style="width: 100%"
                                :disabled="type == 'detail' ? true : false"
                            >
                            </el-date-picker>
                        </el-form-item>
                    </el-col>
                </el-row>
                <el-row>
                    <el-col :span="24">
                        <el-form-item label="整改方" prop="reformDepart">
                            <el-input
                                v-model="form.reformDepart"
                                :disabled="type == 'detail' ? true : false"
                                placeholder="整改方"
                            />
                        </el-form-item>
                    </el-col>
                </el-row>
                <el-row>
                    <el-col :span="24">
                        <el-form-item label="整改结果描述" prop="reformDescription">
                            <el-input
                                type="textarea"
                                v-model="form.reformDescription"
                                placeholder="整改结果描述"
                                :disabled="type == 'detail' ? true : false"
                                style="width: 100%"
                            ></el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
                <el-row>
                    <el-col :span="24">
                        <el-form-item label="整改意见" prop="reformOpinion">
                            <el-input
                                type="textarea"
                                v-model="form.reformOpinion"
                                placeholder="整改意见"
                                :disabled="type == 'detail' ? true : false"
                                style="width: 100%"
                            ></el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
                <el-row>
                    <el-col :span="24">
                        <el-form-item label="备注" prop="remark">
                            <el-input
                                type="textarea"
                                v-model="form.remark"
                                :disabled="type == 'detail' ? true : false"
                                placeholder="备注"
                                style="width: 100%"
                            ></el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
                <el-row>
                    <el-col :span="24">
                        <el-form-item label="附件管理" prop="accessories">
                            <file-upload
                                :dadToSon="dadToSon"
                                @sonToDad="sonToDad"
                                :disabled="type == 'detail' ? true : false"
                            ></file-upload>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <span slot="footer" class="dialog-footer">
                <el-button @click="handleCancel">取 消</el-button>
                <!-- <el-button @click="handleEnclosure">附件管理</el-button> -->
                <el-button
                    type="primary"
                    @click="handleSubmit"
                    :disabled="disabledSave"
                    v-loading.fullscreen.lock="fullscreenLoading"
                    >保存</el-button
                >
            </span>
        </el-dialog>
    </div>
</template>
<script>
import basicData from '@/api/basicData.js'
import fileUpload from '@/components/upload/fileUploadProject.vue'
export default {
    name: 'RectificationTable',
    components: {fileUpload},
    data() {
        return {
            rowData: {},
            visible: false,
            loading: false,
            data: [],
            fullscreenLoading: false,
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            dialogVisible: false,
            dadToSon: {
                bizPath: 'specialproject',
                fileList: [],
            },
            form: {
                type: 0,
                reformFlag: 1,
                accessories: [],
            },
            disabledSave: false,
            userRules: {
                reformDepart: {
                    required: true,
                    message: '请输入整改方',
                    trigger: 'blur',
                },
                reformDate: {
                    required: true,
                    message: '请选择整改日期',
                    trigger: 'blur',
                },
                reformOpinion: {
                    required: true,
                    message: '请输入整改意见',
                    trigger: 'blur',
                },
                reformDescription: {
                    required: true,
                    message: '请输入整改结果描述',
                    trigger: 'blur',
                },
            },
        }
    },
    methods: {
        //取消弹窗
        handleCancel() {
            this.form = {
                reformFlag: 1,
                type: 0,
                accessories: [],
            }
            this.dadToSon = {
                fileList: [],
            }
            this.dialogVisible = false
        },
        sonToDad(data) {
            console.log(data)
            let arr = []
            data.forEach((item) => {
                arr.push({
                    isDele: item.isDele,
                    attachmentName: item.name,
                    attachmentPath: item.url,
                    attachmentSuffix: item.suffix,
                    attachmentType: item.type,
                    type: 0,
                })
            })
            this.accessories = arr
            this.form.accessories = arr
            // 防止用户打开了文件选择框之后不选择文件而出现效验失败
            if (this.form.accessories) {
                this.$refs.form.clearValidate('accessories')
            }
        },
        handleOpen(row) {
            console.log(222)
            console.log('this.rowData', this.rowData)
            this.rowData = row
            this.form = {
                companyName: this.rowData.companyName,
                companyId: this.rowData.companyId,
                roadSegmentName: this.rowData.roadSegmentName,
                roadSegmentId: this.rowData.roadSegmentId,
                projectId: this.rowData.projectId,
                projectName: this.rowData.projectName,
                sourceId: this.rowData.id,
                ...this.form,
            }
            console.log('fdsfsdfdsf', row, this.form)
            this.visible = true
            this.loadData({
                pageBean: {page: 1, pageSize: 20, total: 0},
                sorter: [{direction: 'DESC', property: 'id_'}],
            })
        },
        loadData(param, cb) {
            if (typeof this.topQuery !== 'undefined' && this.topQuery.length !== 0) {
                param.querys = typeof param.querys !== 'undefined' ? param.querys : []
                this.topQuery.forEach((item) => {
                    param.querys.push(item)
                })
                param.querys = this.uniqueFunc(param.querys, 'property')
            }
            if (param.querys && param.querys.length) {
                param.querys.push({
                    group: 'advance',
                    operation: 'EQUAL',
                    property: 'sourceId',
                    relation: 'AND',
                    value: this.rowData.id,
                })
            } else {
                param.querys = [
                    {
                        group: 'advance',
                        operation: 'EQUAL',
                        property: 'sourceId',
                        relation: 'AND',
                        value: this.rowData.id,
                    },
                ]
            }
            this.exportQuery = param

            this.$http
                .post('${yhxt}/bizRectificationCommon/v1/getJsonVo', param)
                .then((response) => {
                    console.log(response)
                    response.data.rows.forEach((item, index) => {
                        item.reformDate = item.bizRectificationCommon.reformDate
                        item.reformDepart = item.bizRectificationCommon.reformDepart
                        item.reformDescription =
                            item.bizRectificationCommon.reformDescription
                        item.reformOpinion = item.bizRectificationCommon.reformOpinion
                        item.indexNo = index + 1
                    })
                    this.data = response.data.rows
                    this.pageResult = {
                        page: response.data.page,
                        pageSize: response.data.pageSize,
                        total: response.data.total,
                    }
                })
                .finally(() => {
                    if (cb) {
                        cb()
                    }
                })
        },
        //新增
        handleAdd() {
            this.projectOptions = []
            this.disabledSave = false
            this.disabled = false
            this.isShowForm = true
            this.dialogVisible = true
            this.type = 'add'
        },
        handleDetail(row) {
            this.dialogVisible = true
            this.type = 'detail'
            this.form = row
        },
        handleRoadSegmentChanged(id) {
            this.roadSegmentOptions.forEach((item) => {
                if (item.id == id) {
                    this.form = {
                        companyName: item.companyName,
                        companyId: item.companyId,
                        roadSegmentName: item.name,
                        roadSegmentId: id,
                        ...this.form,
                    }
                    this.projectOptions = []
                    this.getProjectInfo(id)
                }
            })
        },
        getProjectInfo(roadSegmentId) {
            this.projectParams.querys[0].value = roadSegmentId
            this.$http
                .post('${yhxt}/bizEngineeringProject/v1/getJson', this.projectParams)
                .then((res) => {
                    this.projectOptions = res.data.rows
                })
        },
        handleClose() {
            this.visible = false
            this.data = []
        },
        handleCloseDialog() {
            this.dialogVisible = false
            this.form = {
                reformFlag: 1,
                type: 0,
                accessories: [],
            }
        },
    },
}
</script>
<style lang='scss' scoped>
.table-wrapper{
    height: 300px;
}
/deep/ .ht-table-panel{
    height: 100% !important;
}
/deep/ .htTable-outer {
    height: 100% !important;
}
/deep/.table-refoom .ht-table {
    height: 100% !important;
    max-height: 100%!important;
}
.title{
    font-size: 14px;
    font-weight: bold;
    margin-bottom: 10px;
}
.project-info{
    margin-bottom: 10px;
    display: flex;
    justify-content: start;
    flex-wrap: wrap;
    align-items: center;
    border-bottom: 1px solid #2c5a80;
    border-right: 1px solid #2c5a80;
}
.project-info-item{
    width: 50%;
    font-size: 14px;
    height: 36px;
    padding: 8px;
    box-sizing: border-box;
    border-top: 1px solid #2c5a80;
    border-left: 1px solid #2c5a80;
}
.ht-table-panel{
    background-color: #0d3959!important;
}
</style>